DEF VAR cProgram      AS CHARACTER NO-UNDO.
DEF VAR cAction       AS CHARACTER NO-UNDO.
DEF VAR cTable        AS CHARACTER NO-UNDO.
DEF VAR iTotal        AS INTEGER   NO-UNDO.
DEF VAR iDone         AS INTEGER   NO-UNDO.
DEF VAR iPageNr       AS INTEGER   NO-UNDO.
DEF VAR iCurrentValue AS INTEGER   NO-UNDO.

DEF TEMP-TABLE ttWebPage LIKE aa-web_page
  FIELD oldPageNr AS INT
  INDEX ix1 IS UNIQUE oldPageNr.
  
{System/conversion/conversion_progress.i}  

DEFINE BUFFER b-aa-web_page      FOR aa-web_page.
DEFINE BUFFER b-aa-web_page_link FOR aa-web_page_link.
DEFINE BUFFER b-aa-web_page_item FOR aa-web_page_item.
DEFINE BUFFER b-sp-webmenu       FOR sp-webmenu.
DEFINE BUFFER b-aa-sequence      FOR aa-sequence.

ASSIGN cProgram = THIS-PROCEDURE:FILE-NAME
       cAction  = "Conversion web pages"
       iTotal   = 0
       iDone    = 0
       cTable   = "aa-web_page".
       
DISABLE TRIGGERS FOR LOAD OF b-aa-web_page.
DISABLE TRIGGERS FOR LOAD OF b-aa-web_page_link.
DISABLE TRIGGERS FOR LOAD OF b-aa-web_page_item.
DISABLE TRIGGERS FOR LOAD OF b-sp-webmenu.
DISABLE TRIGGERS FOR LOAD OF b-aa-sequence.

/* >>> Web pages overnemen in temp-table en hernummeren */
iPageNr = 0.
FOR EACH b-aa-web_page BY b-aa-web_page.pagenr.
  CREATE ttWebPage.
  BUFFER-COPY b-aa-web_page TO ttWebPage.
  iPageNr = iPageNr - 1.
  ttWebPage.oldPageNr = b-aa-web_page.pagenr.
  ttWebPage.pagenr    = iPageNr.
END.

FOR EACH ttWebPage WHERE ttWebPage.pagenr < 0.
  ttWebPage.pagenr = ttWebPage.pagenr * -1.
END.  
/* <<< */

RUN DisplayProgress (cProgram, cAction, cTable, iTotal, iDone).

DO TRANSACTION ON ERROR  UNDO, LEAVE 
               ON ENDKEY UNDO, LEAVE:
  
  /* >>> Convert aa-web_page*/
  FOR EACH b-aa-web_page EXCLUSIVE-LOCK.
    iTotal = iTotal + 1.
    DELETE b-aa-web_page.
    iDone = iDone + 1.
  END.
  RUN DisplayProgress (cProgram, cAction, cTable, iTotal, iDone).
  
  FOR EACH ttWebPage.
    iTotal = iTotal + 1.
    CREATE b-aa-web_page.
    BUFFER-COPY ttWebPage EXCEPT ttWebPage.oldPageNr TO b-aa-web_page.
    iDone = iDone + 1.
  END.
  RUN DisplayProgress (cProgram, cAction, cTable, iTotal, iDone).
  /* <<< */
  
  /* >>> Bijwerken aa-page_item naar nieuwe page nummers*/
  FOR EACH b-aa-web_page_item EXCLUSIVE-LOCK.
    iTotal = iTotal + 1.
    IF b-aa-web_page_item.pagenr > 0 THEN 
    DO.
      FIND ttWebPage WHERE ttWebPage.oldPageNr = b-aa-web_page_item.pagenr NO-ERROR.
      IF AVAIL ttWebPage THEN b-aa-web_page_item.pagenr = ttWebPage.pagenr. 
    END.  
    iDone = iDone + 1.
  END.
  RUN DisplayProgress (cProgram, cAction, cTable, iTotal, iDone).
  /* <<< */
  
  /* >>> Bijwerken aa-page_link naar nieuwe page nummers*/
  FOR EACH b-aa-web_page_link EXCLUSIVE-LOCK.
    iTotal = iTotal + 1.
    IF b-aa-web_page_link.pagenr > 0 THEN 
    DO.
      FIND ttWebPage WHERE ttWebPage.oldPageNr = b-aa-web_page_link.pagenr NO-ERROR.
      IF AVAIL ttWebPage THEN b-aa-web_page_link.pagenr = ttWebPage.pagenr. 
    END.
    iDone = iDone + 1.  
  END.
  RUN DisplayProgress (cProgram, cAction, cTable, iTotal, iDone).
  /* <<< */
  
  FIND LAST b-aa-web_page NO-LOCK NO-ERROR.
  IF AVAIL b-aa-web_page THEN iCurrentValue = b-aa-web_page.pagenr.
  ELSE iCurrentValue = 0.
  
  /* >>> Bijwerken sp-webmenu naar nieuwe page nummers*/
  FOR EACH b-sp-webmenu EXCLUSIVE-LOCK.
    iTotal = iTotal + 1.
    IF b-sp-webmenu.pagenr > 0 THEN 
    DO.
      FIND ttWebPage WHERE ttWebPage.oldPageNr = b-sp-webmenu.pagenr NO-ERROR.
      IF AVAIL ttWebPage THEN b-sp-webmenu.pagenr = ttWebPage.pagenr.
      ELSE 
      DO.
        /*In dit geval is er handmatig een pagenummer in sp-webmenu gezet zonder dat er een gerelateerd aa-web_page record gecreeerd is*/
        iCurrentValue = iCurrentValue + 1.
        b-sp-webmenu.pagenr = iCurrentValue.
        
        CREATE b-aa-web_page.
        ASSIGN b-aa-web_page.pagenr              = iCurrentValue
               b-aa-web_page.header_title        = b-sp-webmenu.menu_label
               b-aa-web_page.page_text           = ""
               b-aa-web_page.short_des           = b-sp-webmenu.menu_label
               b-aa-web_page.item_browse_class_1 = "aa_page_column1"
               b-aa-web_page.item_browse_class_2 = "aa_page_column1".
      END. 
    END.
    iDone = iDone + 1.  
  END.
  RUN DisplayProgress (cProgram, cAction, cTable, iTotal, iDone).
  /* <<< */
  
  /* >>> Verwijderen company afhankelijke sequences voor aa-web_page */
  FOR EACH sp-company NO-LOCK.
    iTotal = iTotal + 1.
    FIND b-aa-sequence WHERE b-aa-sequence.sequencecode = sp-company.companycode + "-aa-web_page" NO-LOCK NO-ERROR. 
    IF AVAIL b-aa-sequence THEN 
    DO.
      FIND CURRENT b-aa-sequence EXCLUSIVE-LOCK.
      DELETE b-aa-sequence.
    END.
    iDone = iDone + 1.
  END. 
  RUN DisplayProgress (cProgram, cAction, cTable, iTotal, iDone).
  /* <<< */
   
  /* >>> Maak wanneer nodig nieuwe universele sequence voor aa-web_page */
  iCurrentValue = iCurrentValue + 1.
  FIND b-aa-sequence WHERE b-aa-sequence.sequencecode = "aa-web_page" EXCLUSIVE-LOCK NO-ERROR. 
  IF NOT AVAIL b-aa-sequence THEN 
  DO.
    CREATE b-aa-sequence.
    ASSIGN b-aa-sequence.sequencecode   = "aa-web_page"
           b-aa-sequence.initial_value  = 1
           b-aa-sequence.interval       = 1
           b-aa-sequence.limit          = 2147483647
           b-aa-sequence.cycle_at_limit = TRUE.
  END.
  ASSIGN b-aa-sequence.current_value  = iCurrentValue
         b-aa-sequence.previous_value = iCurrentValue - 1.
  /* <<< */    
  
END.

RUN DisplayProgress (cProgram, cAction, cTable, iTotal, iDone).

/* **********************  Internal Procedures  *********************** */
